package taghelpers;

sub ensureTag
{
	my ($sparser,$tag) = @_;

	my $value = defined $sparser->hasTag($tag) ? $sparser->getTag($tag) : '';
	return $value;
}

sub isPhysHost
{
	my ($sparser) = @_;

	my $jailtype = ensureTag($sparser,"JAIL.Type");
	return $jailtype ne "" ? 1 : 0;
}

sub getIP
{
	my ($sparser) = @_;

	my $ip = ensureTag($sparser,"RemoteAccess");
	$ip = ensureTag($sparser,"JAIL.IP-Address") if ($ip eq "");
	$ip = ensureTag($sparser,"ip") if ($ip eq "");
	$ip = ensureTag($sparser,"ip.eth0") if ($ip eq "");
	$ip = ensureTag($sparser,"ip.wan") if ($ip eq "");
	if ($ip eq "")
	{
		print(STDERR "no IP found in ".$sparser->getFilename());
		exit(1);
	}
	$ip =~ s/\/\w+//g;
	return $ip;
}

sub getContactgroups
{
	my ($sparser) = @_;

	my $contactgroup = ensureTag($sparser,"Check.mon.contactgroup");
	$contactgroup = "lfnet-support, ".$contactgroup if ($contactgroup ne "");
	return $contactgroup;
}

sub getDescriptions
{
	my ($sparser) = @_;

	my $description = ensureTag($sparser,"Check.mon.description");
	my $shortdescription = ensureTag($sparser,"Check.mon.shortdescription");

	if ($shortdescription eq "")
	{
		$shortdescription = substr($description,0,16);
	}
	
	return ($description,$shortdescription);
}

sub getRack
{
	my ($sparser) = @_;

	my $rack = ensureTag($sparser,"Rack");
	$rack = uc($rack) if (/^[a-z][0-9]+/ =~ $rack);
	return $rack;
}

1;
